@@ -65,10 +65,10 @@ cache_path()
 
 get_boot_device()
 {
-	# search in /proc/mounts for the device that is mounted at /live/image
+	# search in /proc/mounts for the device that is mounted at /lib/live/image
 	while read DEVICE MOUNT REST
 	do
-		if [ "${MOUNT}" = "/live/image" ]
+		if [ "${MOUNT}" = "/lib/live/image" ]
 		then
 			echo "${DEVICE}"
 			exit 0
@@ -117,7 +117,7 @@ Eject ()
 
 		if [ -x /usr/bin/eject ]
 		then
-			eject -p -m /live/image >/dev/null 2>&1
+			eject -p -m /lib/live/image >/dev/null 2>&1
 		fi
 
 		if [ "${NOPROMPT}" = "cd" ]
@@ -154,7 +154,16 @@ do
 	cache_path "${path}"
 done
 
-mount -o remount,ro /live/overlay > /dev/null 2>&1
+mount -o remount,ro /lib/live/overlay > /dev/null 2>&1
+
+# Remounting any persistence devices read-only
+for _MOUNT in $(awk '/\/lib\/live\/persistence/ { print $2 }' /proc/mounts)
+do
+	mount -o remount,ro ${_MOUNT} > /dev/null 2>&1
+done
+
+# Flush filesystem buffers
+sync
 
 # Check if we need to eject the drive
 if grep -qs "cdrom-detect/eject=false" /proc/cmdline || \
