@@ -32,6 +32,8 @@ DEBIAN_FRONTEND="noninteractive"
 DEBIAN_PRIORITY="critical"
 DEBCONF_NOWARNINGS="yes"
 
+PROC_OPTIONS="onodev,noexec,nosuid"
+
 Cmdline ()
 {
 	for _PARAMETER in ${_CMDLINE}
@@ -154,7 +156,7 @@ Main ()
 {
 	if [ ! -e /proc/version ]
 	then
-		mount -n -t proc -onodev,noexec,nosuid -odefaults proc /proc
+		mount -n -t proc -o${PROC_OPTIONS} -odefaults proc /proc
 	fi
 
 	_CMDLINE="$(cat /proc/cmdline)"
@@ -168,8 +170,8 @@ Main ()
 	trap 'Trap' EXIT HUP INT QUIT TERM
 
 	# Reading configuration file from filesystem and live-media
-	for _FILE in /etc/live/config.conf /etc/live/config.d/*.conf \
-		     /live/image/live/config.conf /live/image/live/config.d/*.conf
+	for _FILE in /etc/live/config.conf /etc/live/config/* \
+		     /lib/live/image/live/config.conf /lib/live/image/live/config/*
 	do
 		if [ -e "${_FILE}" ]
 		then
